@@ -75,7 +75,7 @@ class SatelliteControlWidget(QtGui.QWidget, ui.Ui_SatelliteDockWidget):
         """Load the file specified in leFile and fill the combobox with the
            available track segments.
         """
-        fname = str(self.leFile.text())
+        fname = unicode(self.leFile.text())
         logging.debug("loading satellite overpasses in file %s", fname)
 
         overpass_segments = mss_util.read_nasa_satellite_prediction(fname)
