@@ -42,22 +42,19 @@ import random
 import string
 from mslib.mss_util import config_loader
 from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
+from mslib.msui import hexagon_dockwidget as hex
 # related third party imports
 from PyQt4 import QtGui, QtCore  # Qt4 bindings
 
 # local application imports
 from mslib.msui import ui_tableview_window as ui
-from mslib.msui import performance_control as perf
-from mslib.msui import performance_control_clientside as perf_cs
 from mslib.msui import flighttrack as ft
 from mslib.msui import mss_qt
+from mslib.msui.performance_settings import MSS_PerformanceSettingsDialog
 
-PERFORMANCE = 0
-PERFORMANCE_OLD = 1
-
-"""
-USER INTERFACE CLASS FlightPlanTableView
-"""
+#
+# USER INTERFACE CLASS FlightPlanTableView
+#
 
 
 class MSSTableViewWindow(mss_qt.MSSViewWindow, ui.Ui_TableViewWindow):
@@ -75,10 +72,12 @@ class MSSTableViewWindow(mss_qt.MSSViewWindow, ui.Ui_TableViewWindow):
         self.setFlightTrackModel(model)
         self.tableWayPoints.setItemDelegate(ft.WaypointDelegate(self))
 
-        self.lblRemainingRange.setVisible(False)
+        toolitems = ["(select to open control)", "Hexagon Control"]
+        self.cbTools.clear()
+        self.cbTools.addItems(toolitems)
 
-        # Dock windows [Performance, Performance_Old].
-        self.docks = [None, None]
+        # Dock windows [Hexagon].
+        self.docks = [None]
 
         # Connect slots and signals.
         self.connect(self.btAddWayPointToFlightTrack, QtCore.SIGNAL("clicked()"),
@@ -87,47 +86,41 @@ class MSSTableViewWindow(mss_qt.MSSViewWindow, ui.Ui_TableViewWindow):
                      self.removeWayPoint)
         self.connect(self.btInvertDirection, QtCore.SIGNAL("clicked()"),
                      self.invertDirection)
-
-        self.connect(self.actionFlightPerformance,
-                     QtCore.SIGNAL("triggered()"),
-                     functools.partial(self.openTool, PERFORMANCE + 1))
-        self.connect(self.actionFlightPerformance_old,
-                     QtCore.SIGNAL("triggered()"),
-                     functools.partial(self.openTool, PERFORMANCE_OLD + 1))
-
         self.connect(self.btViewPerformance, QtCore.SIGNAL("clicked()"),
-                     self.viewPerformance)
+                     self.settingsDlg)
+        # Tool opener.
+        self.connect(self.cbTools, QtCore.SIGNAL("currentIndexChanged(int)"),
+                     self.openTool)
 
         self.resizeColumns()
 
+    def settingsDlg(self):
+        dlg = MSS_PerformanceSettingsDialog(parent=self, settings_dict=self.waypoints_model.performance_settings)
+        dlg.setModal(True)
+        if dlg.exec_() == QtGui.QDialog.Accepted:
+            self.waypoints_model.performance_settings = dlg.get_settings()
+            self.waypoints_model.update_distances(0)
+            self.waypoints_model.saveSettings()
+            self.waypoints_model.emit(QtCore.SIGNAL("dataChanged(QModelIndex,QModelIndex)"),
+                                      self.waypoints_model.index(0, 0),
+                                      self.waypoints_model.index(0, 0))
+            self.resizeColumns()
+        dlg.destroy()
+
     def openTool(self, index):
         """Slot that handles requests to open tool windows.
         """
-        fps = config_loader(dataset="default_VSEC_WMS", default=mss_default.default_VSEC_WMS)
         index = self.controlToBeCreated(index)
         if index >= 0:
-            if index == PERFORMANCE:
-                # Open a flight performance control widget.
-                title = "Flight Performance Control"
-                widget = perf_cs.PerformanceControlWidget(default_FPS=fps, model=self.waypoints_model,
-                                                          wms_cache=config_loader(dataset="wms_cache",
-                                                                                  default=mss_default.wms_cache))
-            elif index == PERFORMANCE_OLD:
-                # Open a flight performance control widget.
-                title = "Flight Performance Service Control"
-                widget = perf.PerformanceControlWidget(default_FPS=fps, model=self.waypoints_model)
+            if index == 0:
+                title = "Hexagon Control"
+                widget = hex.HexagonControlWidget(view=self)
             else:
                 raise IndexError("invalid control index (%i)" % index)
-            # Create the actual dock widget containing <widget>.
-            logging.debug("opening %s" % title)
             self.createDockWidget(index, title, widget)
 
     def invertDirection(self):
         self.waypoints_model.invertDirection()
-        self.setFlightTrackModel(self.waypoints_model)
-        QtGui.QMessageBox.warning(None, "Invert waypoints",
-                                  "Please redraw the map manually, if another view is open!",
-                                  QtGui.QMessageBox.Ok)
 
     def addWayPoint(self):
         """Handler for button <btAddWayPointToFlightTrack>. Adds a new waypoint
@@ -137,10 +130,10 @@ class MSSTableViewWindow(mss_qt.MSSViewWindow, ui.Ui_TableViewWindow):
         index = tableView.currentIndex()
         if not index.isValid():
             row = 0
-            fl = 0
+            flightlevel = 0
         else:
             row = index.row() + 1
-            fl = self.waypoints_model.waypointData(row - 1).flightlevel
+            flightlevel = self.waypoints_model.waypointData(row - 1).flightlevel
         # row = self.waypoints_model.rowCount() # Append to end
         locations = [str(wp.location) for wp in self.waypoints_model.allWaypointData()]
         locname = ""
@@ -165,7 +158,8 @@ class MSSTableViewWindow(mss_qt.MSSViewWindow, ui.Ui_TableViewWindow):
                 j += 1
                 if j == 10:
                     i += 1
-        self.waypoints_model.insertRows(row, waypoints=[ft.Waypoint(lat=0, lon=0, flightlevel=fl, location=locname)])
+        self.waypoints_model.insertRows(
+            row, waypoints=[ft.Waypoint(lat=0, lon=0, flightlevel=flightlevel, location=locname)])
 
         index = self.waypoints_model.index(row, 0)
         tableView = self.tableWayPoints
@@ -183,17 +177,17 @@ class MSSTableViewWindow(mss_qt.MSSViewWindow, ui.Ui_TableViewWindow):
         If the flight track consists of only two points deleting a waypoint
         is not possible. In this case the user is informed correspondingly.
         """
-        wps = self.waypoints_model.allWaypointData(mode=ft.USER)
+        wps = self.waypoints_model.allWaypointData()
         if len(wps) < 3:
             QtGui.QMessageBox.warning(None, "Remove waypoint",
                                       "Cannot remove waypoint, the flight track needs to consist "
                                       "of at least two points.", QtGui.QMessageBox.Ok)
             return False
         else:
-            wp = wps[row]
+            waypoint = wps[row]
             return (QtGui.QMessageBox.question(None, "Remove waypoint",
                                                "Remove waypoint at %.2f/%.2f, flightlevel %.2f?"
-                                               % (wp.lat, wp.lon, wp.flightlevel),
+                                               % (waypoint.lat, waypoint.lon, waypoint.flightlevel),
                                                QtGui.QMessageBox.Yes | QtGui.QMessageBox.No) == QtGui.QMessageBox.Yes)
 
     def removeWayPoint(self):
@@ -218,55 +212,20 @@ class MSSTableViewWindow(mss_qt.MSSViewWindow, ui.Ui_TableViewWindow):
         """
         super(MSSTableViewWindow, self).setFlightTrackModel(model)
         self.tableWayPoints.setModel(self.waypoints_model)
-        self.connect(self.waypoints_model, QtCore.SIGNAL("performanceUpdated()"),
-                     self.viewPerformance)
-        self.connect(self.waypoints_model, QtCore.SIGNAL("dataChanged(QModelIndex,QModelIndex)"),
-                     self.viewPerformance)
-        # Set the performance mode of the flight track.
-        self.viewPerformance()
 
     def viewPerformance(self):
         """Slot to toggle the view mode of the table between 'USER' and
            'PERFORMANCE'.
         """
-        if self.btViewPerformance.isChecked():
-            self.waypoints_model.setMode(ft.PERFORMANCE)
-            # Change the button face colour to "red".
-            palette = QtGui.QPalette(self.btViewPerformance.palette())
-            colour = QtGui.QColor(255, 0, 0)
-            palette.setColor(QtGui.QPalette.Button, colour)
-            self.btViewPerformance.setPalette(palette)
-            # Set the entire table background to red if the performance
-            # computations aren't valid anymore (i.e. after a change).
-            if not self.waypoints_model.performanceValid():
-                palette = QtGui.QPalette(self.tableWayPoints.palette())
-                colour = QtGui.QColor(255, 60, 60)
-                palette.setColor(QtGui.QPalette.Base, colour)
-                colour = QtGui.QColor(255, 80, 80)
-                palette.setColor(QtGui.QPalette.AlternateBase, colour)
-                self.tableWayPoints.setPalette(palette)
-            else:
-                self.tableWayPoints.setPalette(self.palette())
-            # Disable insert/delete buttons.
-            self.btAddWayPointToFlightTrack.setEnabled(False)
-            self.btDeleteWayPoint.setEnabled(False)
-            # Show label that displays remaining range information.
-            self.lblRemainingRange.setText(self.waypoints_model.remainingRangeInfo())
-            self.lblRemainingRange.setVisible(True)
-        else:
-            self.waypoints_model.setMode(ft.USER)
-            # Restore the original button face colour (as inherited from this
-            # window's palette).
-            self.btViewPerformance.setPalette(self.palette())
-            self.tableWayPoints.setPalette(self.palette())
-            self.btAddWayPointToFlightTrack.setEnabled(True)
-            self.btDeleteWayPoint.setEnabled(True)
-            self.lblRemainingRange.setVisible(False)
-
+        # Restore the original button face colour (as inherited from this window's palette).
+        self.btViewPerformance.setPalette(self.palette())
+        self.tableWayPoints.setPalette(self.palette())
+        self.btAddWayPointToFlightTrack.setEnabled(True)
+        self.btDeleteWayPoint.setEnabled(True)
         self.resizeColumns()
 
 
-if __name__ == "__main__":
+def _main():
     # Log everything, and send it to stderr.
     # See http://docs.python.org/library/logging.html for more information
     # on the Python logging module.
@@ -288,10 +247,11 @@ if __name__ == "__main__":
     waypoints_model.insertRows(0, rows=len(initial_waypoints),
                                waypoints=initial_waypoints)
 
-    app = QtGui.QApplication(sys.argv)
-    win = MSSTableViewWindow(model=waypoints_model)
-    win.show()
+    application = QtGui.QApplication(sys.argv)
+    window = MSSTableViewWindow(model=waypoints_model)
+    window.show()
 
-    # waypoints_model.setPerformanceComputation(testperformance)
+    sys.exit(application.exec_())
 
-    sys.exit(app.exec_())
+if __name__ == "__main__":
+    _main()
