@@ -73,22 +73,24 @@ from chameleon import PageTemplateLoader
 
 try:
     import mss_wms_settings
-except ImportError:
+except ImportError, e:
+    logging.warning("Couldn't import mss_wms_settings (ImportError:'{}'), creating dummy config.".format(e))
+
     class mss_wms_settings(object):
         base_dir = os.path.abspath(os.path.dirname(__file__))
         xml_template_location = os.path.join(base_dir, "xml_templates")
         service_name = "OGC:WMS"
         service_title = "Mission Support System Web Map Service"
-        service_abstract = "Your Abstract"
-        service_contact_person = "Your Name"
-        service_contact_organisation = "Your Organization"
-        service_address_type = "postal"
-        service_address = "street"
-        service_city = "Your City"
+        service_abstract = ""
+        service_contact_person = ""
+        service_contact_organisation = ""
+        service_address_type = ""
+        service_address = ""
+        service_city = ""
         service_state_or_province = ""
-        service_post_code = "12345"
-        service_country = "Germany"
-        service_fees = "none"
+        service_post_code = ""
+        service_country = ""
+        service_fees = ""
         service_access_constraints = "This service is intended for research purposes only."
         register_horizontal_layers = []
         register_vertical_layers = []
@@ -96,7 +98,7 @@ except ImportError:
         nwpaccess = {
             "ecmwf_NH_LL05": os.path.join(tempfile.gettempdir(), "mss/grid/ecmwf/netcdf")
         }
-
+        __file__ = None
 
 from mslib.mswms import mss_plot_driver
 
@@ -108,7 +110,9 @@ logging.basicConfig(level=logging.DEBUG,
                     datefmt="%Y-%m-%d %H:%M:%S")
 
 # Chameleon XMl template
-templates = PageTemplateLoader(mss_wms_settings.xml_template_location)
+base_dir = os.path.abspath(os.path.dirname(__file__))
+xml_template_location = os.path.join(base_dir, "xml_templates")
+templates = PageTemplateLoader(mss_wms_settings.__dict__.get("xml_template_location", xml_template_location))
 
 
 class WMSServer(object):
@@ -194,7 +198,7 @@ class WMSServer(object):
         """
         logging.debug("creating service exception..")
         template = templates['service_exception.pt']
-        return_format = "text/xml"
+        # return_format = "text/xml"
         return [template(code=code, text=text), "text/xml"]
 
     def get_capabilities(self, server_url=None):
@@ -214,22 +218,26 @@ class WMSServer(object):
             for layer in self.vsec_layer_registry[dataset].values():
                 vsec_layers.append((dataset, layer))
 
-        return_format = 'text/xml'
-        return_data = template(hsec_layers=hsec_layers, vsec_layers=vsec_layers, server_url=server_url,
-                               service_name=mss_wms_settings.service_name,
-                               service_title=mss_wms_settings.service_title,
-                               service_abstract=mss_wms_settings.service_abstract,
-                               service_contact_person=mss_wms_settings.service_contact_person,
-                               service_contact_organisation=mss_wms_settings.service_contact_organisation,
-                               service_address_type=mss_wms_settings.service_address_type,
-                               service_address=mss_wms_settings.service_address,
-                               service_city=mss_wms_settings.service_city,
-                               service_state_or_province=mss_wms_settings.service_state_or_province,
-                               service_post_code=mss_wms_settings.service_post_code,
-                               service_country=mss_wms_settings.service_country,
-                               service_fees=mss_wms_settings.service_fees,
-                               service_access_constraints=mss_wms_settings.service_access_constraints)
+        # return_format = 'text/xml'
 
+        return_data = template(hsec_layers=hsec_layers, vsec_layers=vsec_layers, server_url=server_url,
+                               service_name=mss_wms_settings.__dict__.get("service_name", "OGC:WMS"),
+                               service_title=mss_wms_settings.__dict__.get("service_title",
+                                                                           "Mission Support System Web Map Service"),
+                               service_abstract=mss_wms_settings.__dict__.get("service_abstract", ""),
+                               service_contact_person=mss_wms_settings.__dict__.get("service_contact_person", ""),
+                               service_contact_organisation=mss_wms_settings.__dict__.get(
+                                   "service_contact_organisation", ""),
+                               service_address_type=mss_wms_settings.__dict__.get("service_address_type", ""),
+                               service_address=mss_wms_settings.__dict__.get("service_address", ""),
+                               service_city=mss_wms_settings.__dict__.get("service_city", ""),
+                               service_state_or_province=mss_wms_settings.__dict__.get("service_state_or_province", ""),
+                               service_post_code=mss_wms_settings.__dict__.get("service_post_code", ""),
+                               service_country=mss_wms_settings.__dict__.get("service_country", ""),
+                               service_fees=mss_wms_settings.__dict__.get("service_fees", ""),
+                               service_access_constraints=mss_wms_settings.__dict__.get(
+                                   "service_access_constraints",
+                                   "This service is intended for research purposes only."))
         return return_data
 
     def produce_plot(self, environ, mode):
